PDResponsiveGridCol class

响应式网格单元配置(描述一个 item 在不同断点占用的列数)。

Constructors

PDResponsiveGridCol({int mobile = 4, int? tablet, int? desktop, required Widget child})
创建一个响应式网格单元。
const

Properties

child Widget
子组件。
final
desktop int?
桌面端占用列数。
final
hashCode int
The hash code for this object.
no setterinherited
mobile int
手机端占用列数。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet int?
平板端占用列数。
final

Methods

currentSpan(int totalColumns) int
根据当前总列数 totalColumns 计算该 item 实际占用的列数。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited