PDTransportException class

transport 层异常(抽象层)。

注意:该异常仅在网络层内部流转,最终必须被转换为 BaseResponse 返回给调用方。

Implemented types

Constructors

PDTransportException({required PDTransportErrorType type, required String message, int? statusCode, dynamic data, Object? error})
创建一个 transport 异常。
const

Properties

data → dynamic
错误响应数据(如果存在)。
final
error Object?
底层错误对象(可选)。
final
hashCode int
The hash code for this object.
no setterinherited
message String
可读错误信息(通常来自底层网络库/自定义映射)。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP 状态码(如果存在)。
final
type PDTransportErrorType
错误类型。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited