PDValueValidator class
基于 PDDeepComparator 的静态便捷方法集合。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
batchCompare(
List< List> pairs) → List<PDComparisonResult> - 批量比较对象对,返回每一对的比较结果。
-
compare(
dynamic obj1, dynamic obj2) → PDComparisonResult - 深度比较两个对象并返回详细差异信息。
-
deepEquals(
dynamic obj1, dynamic obj2) → bool - 深度判断两个对象是否相等。
-
hasDuplicates(
List list) → bool - 判断列表中是否存在深度意义上的重复元素。
-
removeDuplicates(
List list) → List - 基于深度比较移除列表中的重复元素(保留第一次出现的元素)。
-
wrap(
dynamic value) → PDComparableWrapper - 将任意对象包装为可用于集合去重/比较的对象。